@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.38'; # VERSION
+our $VERSION = '1.39'; # VERSION
 
 our %SPEC;
 
@@ -31,7 +31,7 @@ _
 sub ltrim {
     my %args = @_;
     my ($in, $out) = ($args{in}, $args{out});
-    my $nl  = $args{nl} // 0;
+    my $nl  = $args{strip_newline} // 0;
 
     while (my ($index, $item) = each @$in) {
         my @lt;
@@ -49,9 +49,8 @@ sub ltrim {
 1;
 # ABSTRACT: Strip whitespace at the beginning of each line of text
 
-
-
 __END__
+
 =pod
 
 =encoding utf-8
@@ -62,7 +61,7 @@ Data::Unixish::ltrim - Strip whitespace at the beginning of each line of text
 
 =head1 VERSION
 
-version 1.38
+version 1.39
 
 =head1 SYNOPSIS
 
@@ -98,8 +97,6 @@ None are exported by default, but they are exportable.
 
 =head2 ltrim(%args) -> [status, msg, result, meta]
 
-Strip whitespace at the beginning of each line of text.
-
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -123,4 +120,3 @@ Return value:
 Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
 
 =cut
-
